@@ -1,40 +1,27 @@
-/***************************************************************************
- *   Copyright (C) 2015 Kai Uwe Broulik <kde@privat.broulik.de>            *
- *                                                                         *
- *   This program is free software; you can redistribute it and/or modify  *
- *   it under the terms of the GNU General Public License as published by  *
- *   the Free Software Foundation; either version 2 of the License, or     *
- *   (at your option) any later version.                                   *
- *                                                                         *
- *   This program is distributed in the hope that it will be useful,       *
- *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
- *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
- *   GNU General Public License for more details.                          *
- *                                                                         *
- *   You should have received a copy of the GNU General Public License     *
- *   along with this program; if not, write to the                         *
- *   Free Software Foundation, Inc.,                                       *
- *   51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA            *
- ***************************************************************************/
+/*
+ *   SPDX-FileCopyrightText: 2015 Kai Uwe Broulik <kde@privat.broulik.de>
+ *
+ *   SPDX-License-Identifier: GPL-2.0-or-later
+ */
 
 #include "batterymodel.h"
 
 #include <Solid/DeviceNotifier>
 
-#include <QtQml>
 #include <QQmlEngine>
+#include <QtQml>
 
-
-BatteryModel::BatteryModel(QObject *parent) : QAbstractListModel(parent)
+BatteryModel::BatteryModel(QObject *parent)
+    : QAbstractListModel(parent)
 {
-    qmlRegisterUncreatableType<Solid::Battery>("org.kde.kinfocenter.energy.private", 1, 0, "Battery",
-            QStringLiteral("Use Solid::Battery"));
+    qmlRegisterUncreatableType<Solid::Battery>("org.kde.kinfocenter.energy.private", 1, 0, "Battery", QStringLiteral("Use Solid::Battery"));
 
     m_batteries = Solid::Device::listFromType(Solid::DeviceInterface::Battery);
 
     connect(Solid::DeviceNotifier::instance(), &Solid::DeviceNotifier::deviceAdded, this, [this](const QString &udi) {
-
-        auto it = std::find_if(m_batteries.constBegin(), m_batteries.constEnd(), [&udi](const Solid::Device &dev) {return dev.udi() == udi;});
+        auto it = std::find_if(m_batteries.constBegin(), m_batteries.constEnd(), [&udi](const Solid::Device &dev) {
+            return dev.udi() == udi;
+        });
         if (it != m_batteries.constEnd()) {
             return;
         }
@@ -49,14 +36,15 @@ BatteryModel::BatteryModel(QObject *parent) : QAbstractListModel(parent)
         }
     });
     connect(Solid::DeviceNotifier::instance(), &Solid::DeviceNotifier::deviceRemoved, this, [this](const QString &udi) {
-        auto it = std::find_if(m_batteries.constBegin(), m_batteries.constEnd(), [&udi](const Solid::Device &dev) {return dev.udi() == udi;});
+        auto it = std::find_if(m_batteries.constBegin(), m_batteries.constEnd(), [&udi](const Solid::Device &dev) {
+            return dev.udi() == udi;
+        });
         if (it == m_batteries.constEnd()) {
             return;
         }
 
         int index = std::distance(m_batteries.constBegin(), it);
 
-
         beginRemoveRows(QModelIndex(), index, index);
         m_batteries.removeAt(index);
         endRemoveRows();
@@ -99,10 +87,5 @@ int BatteryModel::rowCount(const QModelIndex &parent) const
 
 QHash<int, QByteArray> BatteryModel::roleNames() const
 {
-    return {
-        {BatteryRole, "battery"},
-        {VendorRole, "vendor"},
-        {ProductRole, "product"},
-        {UdiRole, "udi"}
-    };
+    return {{BatteryRole, "battery"}, {VendorRole, "vendor"}, {ProductRole, "product"}, {UdiRole, "udi"}};
 }
