@@ -7,7 +7,6 @@
 #ifndef KCM_ENERGYINFO_H
 #define KCM_ENERGYINFO_H
 
-#include "wakeupmodel.h"
 #include <KQuickAddons/ConfigModule>
 class BatteryModel;
 
@@ -17,8 +16,6 @@ class KCMEnergyInfo : public KQuickAddons::ConfigModule
 
     Q_PROPERTY(BatteryModel *batteries READ batteries CONSTANT)
 
-    Q_PROPERTY(WakeUpModel *wakeUps READ wakeUps CONSTANT)
-
 public:
     explicit KCMEnergyInfo(QObject *parent, const KPluginMetaData &data, const QVariantList &args);
     ~KCMEnergyInfo() override = default;
@@ -28,17 +25,9 @@ public:
         return m_batteries;
     }
 
-    WakeUpModel *wakeUps() const
-    {
-        return m_wakeUps;
-    }
-
 private:
     BatteryModel *m_batteries = nullptr;
 
-    WakeUpModel *m_wakeUps = nullptr;
-
-    int m_wakeUpsCount = 0;
 };
 
 Q_DECLARE_METATYPE(QList<QPointF>)
